/****************************************************************
 *								*
 * Copyright (c) 2001-2019 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef BIT_SET_DEFINED

#include "gdsroot.h"

/* Declare parms for bit_set.c */

uint4 bit_set (block_id bit, sm_uc_ptr_t base);

#define BIT_SET_DEFINED

#endif
